=====
Pricing module for Ralph
=====

.. image:: https://pypip.in/v/scrooge/badge.png
    :target: https://crate.io/packages/scrooge/
    :alt: Latest PyPI version


.. image:: https://pypip.in/d/scrooge/badge.svg
    :target: https://crate.io/packages/scrooge/
    :alt: Number of PyPI downloads


.. image:: https://travis-ci.org/allegro/ralph_pricing.svg?branch=develop
    :target: https://travis-ci.org/allegro/ralph_pricing


.. image:: https://coveralls.io/repos/allegro/ralph_pricing/badge.png?branch=develop
  :target: https://coveralls.io/r/allegro/ralph_pricing?branch=develop


.. image:: https://pypip.in/license/scrooge/badge.svg
    :target: https://crate.io/packages/scrooge/

The pricing module aggregates data from Ralph and from Ralph Assets to generate
reports showing the prices of the servers in inventory per their owners daily.
